endConnection method
void
endConnection()
Ends the current connection as the server closing it.
Implementation
void endConnection() => current.close();
Ends the current connection as the server closing it.
void endConnection() => current.close();