SendTransactionFeature class final

The wallet can process sendTransaction.

Inheritance

Constructors

SendTransactionFeature({required int maxMessages, bool extraCurrencySupported = false, Set<TransactionItemType>? itemTypes})
Creates a SendTransaction feature descriptor.
const

Properties

extraCurrencySupported bool
Whether the wallet supports extra currencies.
final
hashCode int
The hash code for this object.
no setterinherited
itemTypes Set<TransactionItemType>?
Structured item types the wallet accepts.
final
maxMessages int
Maximum number of messages accepted in a single transaction.
final
name String
The feature name as it appears on the wire.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited