DevicePlatform enum
Platform the connected wallet application runs on.
Values
- iphone → const DevicePlatform
-
iPhone.
- ipad → const DevicePlatform
-
iPad.
- android → const DevicePlatform
-
Android phone or tablet.
- windows → const DevicePlatform
-
Windows desktop.
- mac → const DevicePlatform
-
macOS desktop.
- linux → const DevicePlatform
-
Linux desktop.
- browser → const DevicePlatform
-
Browser extension or web wallet.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryParse(
String value) → DevicePlatform? -
Parses a platform name from
DeviceInfo.platform.
Constants
-
values
→ const List<
DevicePlatform> - A constant List of the values in this enum, in order of their declaration.