WalletResponseError class final
The wallet refused or failed the request.
- Inheritance
-
- Object
- WalletResponse
- WalletResponseError
- Annotations
-
- @immutable
Constructors
- WalletResponseError(String id, TonConnectProtocolError error, {Object? data})
-
Creates an error response.
const
Properties
- data → Object?
-
Optional wallet-supplied detail. Shape is not specified.
final
- error → TonConnectProtocolError
-
Why the wallet refused.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The id of the request this answers.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited